@@ -101,6 +101,33 @@ class BillPayments(Resource):
                         }
                     })
 
+                invoices = payload.get("invoice_payments", [])
+
+                for i in range(len(invoices)):
+                    invoice = {}
+                    if 'amount' in invoices[i].keys():
+                        invoice.update({
+                            "Amount": invoices[i].get("amount", "")
+                        })
+
+                    if 'invoice_id' in invoices[i].keys():
+                        invoice.update({
+                            "LinkedTxn": [
+                                {
+                                    "TxnId": invoices[i].get('invoice_id',""),
+                                    "TxnType": payload.get("payment_type", "Bill")
+                                }
+                            ]
+                        })
+                    
+                    invoices[i] = invoice
+
+                # if invoices has data in it
+                if bool(invoices):
+                    data.update({
+                        "Line": invoices
+                    })
+
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
 
