@@ -1,4 +1,4 @@
-from Resources.resource import Resource
+from erp_sync.Resources.resource import Resource
 
 
 class Customer(Resource):
@@ -155,6 +155,66 @@ class Customer(Resource):
                         }
                     })
 
+            # If client type is SAP
+            elif super().get_client_type() == super().SAP:
+                bp_information = {
+                    "CardType": "CUSTOMER",
+                }
+                if 'first_name' in payload.keys() and 'last_name' in payload.keys():
+                    bp_information.update({
+                        "CardName": f'{payload.get("first_name","")} {payload.get("last_name","")}'
+                    })
+
+                if 'phone' in payload.keys():
+                    bp_information.update({
+                        "Telephone1": payload.get("phone", ""),
+                        "Telephone2": payload.get("phone", "")
+                    })
+
+                if 'mobile' in payload.keys():
+                    bp_information.update({
+                        "MobilePhone": payload.get("mobile", "")
+                    })
+
+                if 'email' in payload.keys():
+                    bp_information.update({
+                        "Email": payload.get("email", "")
+                    })
+
+                if 'tax_pin' in payload.keys():
+                    bp_information.update({
+                        "KRAPIN": payload.get("tax_pin", "")
+                    })
+
+                if 'customer_code' in payload.keys():
+                    bp_information.update({
+                        "CardCode": payload.get("customer_code", "")
+                    })
+                
+                if 'GroupCode' in additional_properties.keys():
+                    bp_information.update({
+                        "GroupCode": additional_properties.get("GroupCode", {})
+                    })
+                    
+                    additional_properties.pop("GroupCode")
+                
+                if 'Fax' in additional_properties.keys():
+                    bp_information.update({
+                        "Fax": additional_properties.get("Fax", {})
+                    })
+                    
+                    additional_properties.pop("Fax")
+                
+                if 'phone2' in additional_properties.keys():
+                    bp_information.update({
+                        "Telephone2": additional_properties.get("phone2", {})
+                    })
+                    
+                    additional_properties.pop("phone2")
+                
+                data.update({
+                    "BPInformation": bp_information
+                })
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
 
@@ -277,35 +337,34 @@ class Customer(Resource):
 
             payload = super().response()
 
+            data = payload
+
             if 'customers' in payload.keys():
                 data = payload.get("customers", [])
             elif 'resource' in payload.keys():
                 data = payload.get("resource", [])
-            else:
-                # confirms if a single object was read from the database
-                if isinstance(payload, dict):
-                    data = [payload]
-                else:
-                    data = []
+
 
             # confirms if a single object was read from the database
             if isinstance(data, dict):
                 data = [data]
-            else:
-                data = []
 
-            if len(data) > 0:
+            # confirms if data is a list
+            if isinstance(data, list):
 
-                for i in range(len(data)):
-                    if 'family_name' in data[i].keys():
-                        data[i]['first_name'] = data[i].pop('family_name')
+                if len(data) > 0:
 
-                    if 'given_name' in data[i].keys():
-                        data[i]['last_name'] = data[i].pop('given_name')
+                    for i in range(len(data)):
+                        if 'family_name' in data[i].keys():
+                            data[i]['first_name'] = data[i].pop('family_name')
 
-                # confirms if a single object was read from the database
-                if not bool(payload):
-                    payload["customers"] = [data]
+                        if 'given_name' in data[i].keys():
+                            data[i]['last_name'] = data[i].pop('given_name')
+                        
+            if 'customers' in payload.keys():
+                payload["customers"] = data
+            elif 'resource' in payload.keys():
+                payload["resource"] = data
 
             super().set_response(payload)
 
