@@ -131,10 +131,10 @@ class Invoices(Resource):
 
         if operation == super().NEW or operation == super().UPDATE:
 
-            data["type"] = ""
+            data["type"] = "SalesInvoice"
 
             if 'invoice_type' in payload.keys():
-                data["type"] = payload.get("invoice_type", "")
+                data["type"] = payload.get("invoice_type", "SalesInvoice")
 
             additional_properties = payload.get("additional_properties", {})
 
@@ -218,10 +218,15 @@ class Invoices(Resource):
             elif super().get_client_type() == super().SAP:
                 header = {}
 
+                if 'customer_ledger_id' in payload.keys():
+                    header.update({
+                        "CardCode": payload.get("customer_ledger_id", "")
+                    })
+
                 if 'invoice_type' in payload.keys():
                     header.update({
-                        "ObjectType": payload.get("invoice_type", ""),
-                        "InvoiceType": payload.get("invoice_type", "")
+                        "ObjectType": data.get("type", ""),
+                        "InvoiceType": data.get("type", "")
                     })
 
                 if 'due_date' in payload.keys():
@@ -269,13 +274,6 @@ class Invoices(Resource):
                     
                     additional_properties.pop("DocCurrency")
                 
-                if 'CardCode' in additional_properties.keys():
-                    header.update({
-                        "CardCode": additional_properties.get("CardCode", "")
-                    })
-                    
-                    additional_properties.pop("CardCode")
-                
                 if 'SourceNumber' in additional_properties.keys():
                     header.update({
                         "SourceNumber": additional_properties.get("SourceNumber", "")
@@ -303,9 +301,9 @@ class Invoices(Resource):
                     if 'account_id' in line_items[i].keys():
                         line_items[i]['AcctCode'] = line_items[i].pop(
                             'account_id')
-                    if 'line_item_id' in line_items[i].keys():
+                    if 'item_ledger_id' in line_items[i].keys():
                         line_items[i]['ItemCode'] = line_items[i].pop(
-                            'line_item_id')
+                            'item_ledger_id')
                     if 'quantity' in line_items[i].keys():
                         line_items[i]['Quantity'] = line_items[i].pop(
                             'quantity')
@@ -381,9 +379,9 @@ class Invoices(Resource):
                         line_items[i]['AccountID'] = line_items[i].pop(
                             'account_id')
 
-                    if 'line_item_id' in line_items[i].keys():
+                    if 'item_ledger_id' in line_items[i].keys():
                         line_items[i]['LineItemID'] = line_items[i].pop(
-                            'line_item_id')
+                            'item_ledger_id')
 
                     if 'quantity' in line_items[i].keys():
                         line_items[i]['Quantity'] = line_items[i].pop(
