@@ -97,20 +97,16 @@ class Payments(Resource):
 
         if operation == super().NEW or operation == super().UPDATE:
 
+            data["type"] = "SalesPayment"
+
+            if 'payment_type' in payload.keys():
+                data["type"] = payload.get("payment_type", "SalesPayment")
+
             additional_properties = payload.get("additional_properties", {})
 
             # If client type is Quickbooks Online
             if super().get_client_type() == super().QBO:
 
-                data = {"type": "SalesPayment"}
-
-                if 'type' in additional_properties.keys():
-                    data.update({
-                        "type": additional_properties.get("type", "SalesPayment")
-                    })
-
-                    additional_properties.pop("type")
-
                 if 'amount' in payload.keys():
                     data.update({
                         "TotalAmt": payload.get("amount", "")
@@ -123,33 +119,26 @@ class Payments(Resource):
                         }
                     })
 
-                if 'account_id' in payload.keys():
-                    data.update({
-                        "DepositToAccountRef": {
-                            "value": payload.get("account_id", "")
-                        }
-                    })
-
                 if 'reference' in payload.keys():
                     data.update({
                         "PaymentRefNum": payload.get("reference", "")
                     })
                 
-                invoices = payload.get("invoice_payments", [])
+                invoices = payload.get("invoices", [])
 
                 for i in range(len(invoices)):
                     invoice = {}
                     if 'amount' in invoices[i].keys():
                         invoice.update({
-                            "Amount": invoices[i].get("amount", "")
+                            "Amount": payload.get("amount", "")
                         })
 
                     if 'invoice_id' in invoices[i].keys():
                         invoice.update({
                             "LinkedTxn": [
                                 {
-                                    "TxnId": invoices[i].get('invoice_id',""),
-                                    "TxnType": payload.get("payment_type", "Invoice")
+                                    "TxnId": invoices[i].pop('invoice_id'),
+                                    "TxnType": "Invoice"
                                 }
                             ]
                         })
@@ -165,15 +154,6 @@ class Payments(Resource):
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
 
-                data = {"type": "SalesPayment"}
-
-                if 'type' in additional_properties.keys():
-                    data.update({
-                        "type": additional_properties.get("type", "SalesPayment")
-                    })
-
-                    additional_properties.pop("type")
-
                 payment = {}
 
                 if 'customer_id' in payload.keys():
@@ -201,7 +181,7 @@ class Payments(Resource):
                         "date": payload.get("date", "")
                     })
 
-                invoices = payload.get("invoice_payments", [])
+                invoices = payload.get("invoices", [])
 
                 for i in range(len(invoices)):
                     if 'invoice_id' in invoices[i].keys():
@@ -210,11 +190,6 @@ class Payments(Resource):
                     if 'amount' in invoices[i].keys():
                         invoices[i]['amount_applied'] = invoices[i].pop(
                             'amount')
-                    
-                    invoices[i].pop('payment_date')
-                    invoices[i].pop('payment_reference')
-                    invoices[i].pop('payment_type')
-                    invoices[i].pop('account_id')
 
                 # if invoices has data in it
                 if bool(invoices):
@@ -231,15 +206,24 @@ class Payments(Resource):
             elif super().get_client_type() == super().SAP:
                 header = {}
 
-                if 'payment_type' in payload.keys():
-                    header.update({
-                        "Type": payload.get("payment_type", "")
-                    })
+                header.update({
+                    "Type": data.get("type", "")
+                })
 
                 if 'date' in payload.keys():
                     header.update({
                         "DocDate": payload.get("date", "")
                     })
+
+                if 'customer_id' in payload.keys():
+                    header.update({
+                        "CardCode": payload.get("customer_id", "")
+                    })
+
+                if 'invoice_id' in payload.keys():
+                    header.update({
+                        "InvoiceDocEntry": payload.get("invoice_id", "")
+                    })
                 
                 if 'SourceNumber' in additional_properties.keys():
                     header.update({
@@ -269,20 +253,6 @@ class Payments(Resource):
                     
                     additional_properties.pop("CardType")
                 
-                if 'CardCode' in additional_properties.keys():
-                    header.update({
-                        "CardCode": additional_properties.get("CardCode", "")
-                    })
-                    
-                    additional_properties.pop("CardCode")
-                
-                if 'InvoiceDocEntry' in additional_properties.keys():
-                    header.update({
-                        "InvoiceDocEntry": additional_properties.get("InvoiceDocEntry", "")
-                    })
-                    
-                    additional_properties.pop("InvoiceDocEntry")
-                
                 if 'ReceiptNo' in additional_properties.keys():
                     header.update({
                         "ReceiptNo": additional_properties.get("ReceiptNo", "")
@@ -293,7 +263,6 @@ class Payments(Resource):
                 invoice_payments = payload.get("invoice_payments", [])
 
                 for i in range(len(invoice_payments)):
-                    invoice_payments[i].pop('invoice_id')
                     if 'payment_date' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentDate'] = invoice_payments[i].pop(
                             'payment_date')
@@ -347,17 +316,16 @@ class Payments(Resource):
                 if 'customer_id' in payload.keys():
                     payment.update({
                         "Account": {
-                            "AccountID": payload.get("account_id", "")
+                            "AccountID": payload.get("customer_id", "")
                         }
                     })
 
-                if 'invoice_id' in payload.keys():
+                if 'invoice' in additional_properties.keys():
                     payment.update({
-                        "Invoice": {
-                            "InvoiceID": payload.get("invoice_id", ""),
-                            "LineItems": payload.get("invoice_payments", []),
-                        }
+                        "Invoice": additional_properties.get("invoice", {})
                     })
+                    
+                    additional_properties.pop("invoice")
 
                 if bool(payment):
                     data.update({
